@@ -81,6 +81,28 @@ def display2(videodev, save = False,
          passfile="~/.pycamfw_userpass"):
     """
     """
+    #sname,sfilenamea,sme,sfilenamea,sfilenamea,sfourcc,saviout
+
+    def setupsave():
+        sname = "rec"
+        sname = videodev
+        sname = sname.replace("http","")
+        sname = sname.replace("//","")
+        sname = sname.replace(":","")
+        sname = sname.replace("5000/video","")
+        sname = sname.replace("8000/video","")
+
+        sfilenamea = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
+        sme = socket.gethostname()
+        sfilenamea = f"{sme}_{sname}_{sfilenamea}.avi"
+        sfilenamea = os.path.expanduser("~/" + sfilenamea)
+        sfourcc = cv2.VideoWriter_fourcc(*'XVID')
+        saviout = cv2.VideoWriter( sfilenamea,sfourcc,25.0, (640,480))
+        print( sfilenamea )
+        print( sfilenamea )
+        print( sfilenamea )
+        print( sfilenamea )
+        return sfilenamea,saviout
 
     def get_stream():
         # localuser
@@ -188,18 +210,7 @@ def display2(videodev, save = False,
         sfilename = ""
         sfilenamea = ""
         if save:
-            sname = "rec"
-            sfilenamea = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
-            sme = socket.gethostname()
-            sfilenamea = f"{sme}{sname}_{sfilenamea}.avi"
-            sfilenamea = os.path.expanduser("~/" + sfilenamea)
-            sfourcc = cv2.VideoWriter_fourcc(*'XVID')
-            saviout = cv2.VideoWriter( sfilenamea,sfourcc,25.0, (640,480))
-            print( sfilenamea )
-            print( sfilenamea )
-            print( sfilenamea )
-            print( sfilenamea )
-
+            sfilenamea,saviout = setupsave()
 
         first = True
 
@@ -239,12 +250,12 @@ def display2(videodev, save = False,
                             for i8 in range(1): # I decimate and remove delay
                                 #print("1-", flush=True,end="")
                                 bytex += stream.read(1024*10)
-                                BPS+=len(bytex)/1024
-                                if len(bytex)>0:
-                                    FPS+=1
                                 a = bytex.find(b'\xff\xd8') #frame starting
                                 b = bytex.find(b'\xff\xd9') #frame ending
                                 if a != -1 and b != -1:
+                                    BPS+=len(bytex)/1024
+                                    if len(bytex)>0:
+                                        FPS+=1
                                     jpg = bytex[a:b+2]
                                     bytex = bytex[b+2:]
                                     frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
@@ -304,6 +315,12 @@ def display2(videodev, save = False,
                 # time.sleep(0.2)
                 key = cv2.waitKey(1)
 
+                if (not frame is None) and (rpi_name!="") and (key == ord('a')):
+                    print("A PRESSED! - saving AVI")
+                    save = True
+                    sfilenamea,saviout = setupsave()
+                    print(">>>", sfilenamea )
+
                 if (not frame is None) and (rpi_name!="") and (key == ord('q')):
                     print("Q PRESSED!")
                     sys.exit(1)
